---
title: "Set up your data for IPEDS Admissions processing"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Set up your data for IPEDS Admissions processing}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup, include=FALSE}
library(IPEDSuploadables)
```

```{r specsimport, eval = FALSE, echo = FALSE}
#this chunk is only used during interactive session by the package maintainers, if the requirements have been updated

tryCatch(specs_ADM <-  googlesheets4::read_sheet('1j8D2bHKhteW3Cyant0nKw8mvTWXgHSow6cX6uOXS44M'),
        error = function(x) message("Google Sheet unavailable"),
        warning = function(y) message("There was a warning"))

usethis::use_data(specs_ADM, overwrite = TRUE) 
```

## To use the `produce_adm_report` function, your student admissions data must be in the format described below

>
* One row per person
* One IPEDS Unitid per file
* Columns with values and types as described below (additional columns are allowed)

This population should meet IPEDS rules for inclusion on this report (those seeking to be admitted to undergraduate programs as first-time full-time degree/certificate seekers, including transfer students).  This data file is not necessary if your institution has an open-admissions policy for entering first-time students.

```{r specstable, echo=FALSE, warning=FALSE, message=FALSE}
library(magrittr)
specs_ADM$ACCEPTABLE_VALUES <- stringr::str_replace_all(specs_ADM$ACCEPTABLE_VALUES, pattern = "\\n", replacement = "<br>")
knitr::kable(specs_ADM, 
             format = 'html',
             escape = FALSE,
             col.names = c('Column Name', 'Column Type', 'Acceptable Value - Definition')) %>%
    kableExtra::kable_styling(bootstrap_options = "striped") %>%
    kableExtra::column_spec(2, italic = TRUE, width = '8em')
```

